capture log close
set more 1


**********************
* COUNTRY 1 ANALYSIS *
**********************

use country_1_data.dta, clear

* treatment = 0 for optimistic prior, treatment = 1 for pessimistic prior 
* signal_i: private signal. Values: 0 (low), 1 (medium), 2 (high)
* action_i: action in the game. Values: 0 (withdraw), 1 (rollover)

***********
* Table 7 *
***********

* Recreates table 7: percentage of rollover decisions, by signal, and test of statistical significance
* Focus on action_i = 1 (rollover)

bysort signal_i: tab action_i if treatment==0&Period>10
bysort signal_i: tab action_i if treatment==1&Period>10

ttest action_i if signal==0&Period>10, by(treatment)
ttest action_i if signal==1&Period>10, by(treatment)
ttest action_i if signal==2&Period>10, by(treatment)

* Calculate default rate for Medium theta (theta=1)
gen default = 1 - attack_success
ttest default if theta==1&Period>10, by(treatment)


**********************
* COUNTRY 2 ANALYSIS *
**********************

use country_2_data.dta, clear

* location = 0 for NYU, = 1 for UCSD
* treatment = 1 for optimistic prior, alpha=1, s=1  
*           = 2 for optimistic prior, alpha=0.33, s=0.75
*           = 3 for optimistic prior, alpha=0.75, s=0.33
*           = 4 for optimistic prior, alpha=0.75, s=0.75
*           = 4.5 for optimistic prior, alpha=0.33, s=0.33
*           = 5 for pessimistic prior, alpha=1, s=1  
*           = 6 for pessimistic prior, alpha=0.33, s=0.75
*           = 7 for pessimistic prior, alpha=0.75, s=0.33
*           = 8 for pessimistic prior, alpha=0.75, s=0.75
*           = 8.5 for pessimistic prior, alpha=0.33, s=0.33
* signal_i: private signal. Values: 0 (low), 1 (medium), 2 (high)
* action_i: action in the game. Values: 0 (withdraw), 1 (rollover)
* y: public signal about the number of subjects who withdrew in Country 1. Values: 0, 1, 2
* idd: subject id, across treatments
* ppair: pair id, across treatments

gsort ppair Period idd
gen action_other = .
replace action_other = action_i[_n+1] if ppair==ppair[_n+1]&Period==Period[_n+1]
replace action_other = action_i[_n-1] if ppair==ppair[_n-1]&Period==Period[_n-1]
gen signal_other = .
replace signal_other = signal_i[_n+1] if ppair==ppair[_n+1]&Period==Period[_n+1]
replace signal_other = signal_i[_n-1] if ppair==ppair[_n-1]&Period==Period[_n-1]

****************
* HYPOTHESIS 1 *
****************

* Generate dummies for optimistic and pessimistic priors, for each combination of (s,alpha)
gen d_15 = .
replace d_15 = 0 if treatment == 1
replace d_15 = 1 if treatment == 5
gen d_26 = .
replace d_26 = 0 if treatment == 2
replace d_26 = 1 if treatment == 6
gen d_37 = .
replace d_37 = 0 if treatment == 3
replace d_37 = 1 if treatment == 7
gen d_48 = .
replace d_48 = 0 if treatment == 4
replace d_48 = 1 if treatment == 8
gen d_45_85 = .
replace d_45_85 = 0 if treatment==4.5
replace d_45_85 = 1 if treatment==8.5

* Generate variable for number of people rolling over
gen y_rollover = .
replace y_rollover = 0 if y==2
replace y_rollover = 1 if y==1
replace y_rollover = 2 if y==0

* Interacted variables
gen signal_i_15 = signal_i*d_15
gen signal_i_26 = signal_i*d_26
gen signal_i_37 = signal_i*d_37
gen signal_i_48 = signal_i*d_48
gen signal_i_45_85 = signal_i*d_45_85

gen y_rollover_15 = y_rollover*d_15
gen y_rollover_26 = y_rollover*d_26
gen y_rollover_37 = y_rollover*d_37
gen y_rollover_48 = y_rollover*d_48
gen y_rollover_45_85 = y_rollover*d_45_85

gen d_15_loc = d_15*location
gen d_26_loc = d_26*location
gen d_37_loc = d_37*location
gen d_48_loc = d_48*location
gen d_45_85_loc = d_45_85*location

gen signal_i_loc = signal_i*location
gen signal_i_15_loc = signal_i_15*location
gen signal_i_26_loc = signal_i_26*location
gen signal_i_37_loc = signal_i_37*location
gen signal_i_48_loc = signal_i_48*location
gen signal_i_45_85_loc = signal_i_45_85*location

gen y_rollover_loc = y_rollover*location
gen y_rollover_15_loc = y_rollover_15*location
gen y_rollover_26_loc = y_rollover_26*location
gen y_rollover_37_loc = y_rollover_37*location
gen y_rollover_48_loc = y_rollover_48*location
gen y_rollover_45_85_loc = y_rollover_45_85*location

*****************************************
* MAIN REGRESSION, Tables 8, 11, and 12 *
*****************************************

* Column 5
xtlogit action_i signal_i y_rollover d_15 signal_i_15 y_rollover_15 location d_15_loc signal_i_loc signal_i_15_loc y_rollover_loc y_rollover_15_loc if Period>10, i(idd)
mfx, predict(pu0)
* Column 2
xtlogit action_i signal_i y_rollover d_26 signal_i_26 y_rollover_26 location d_26_loc signal_i_loc signal_i_26_loc y_rollover_loc y_rollover_26_loc if Period>10, i(idd)
mfx, predict(pu0)
* Column 3
xtlogit action_i signal_i y_rollover d_37 signal_i_37 y_rollover_37 location d_37_loc signal_i_loc signal_i_37_loc y_rollover_loc y_rollover_37_loc if Period>10, i(idd)
mfx, predict(pu0)
* Column 4
xtlogit action_i signal_i y_rollover d_48 signal_i_48 y_rollover_48 location d_48_loc signal_i_loc signal_i_48_loc y_rollover_loc y_rollover_48_loc if Period>10, i(idd)
mfx, predict(pu0)
* Column 1
xtlogit action_i signal_i y_rollover d_45_85 signal_i_45_85 y_rollover_45_85 d_45_85_loc location signal_i_loc signal_i_45_85_loc y_rollover_loc y_rollover_45_85_loc if Period>10, i(idd)
mfx, predict(pu0)



*************************************************************
* HYPOTHESIS 2: FREQUENCIES OF WITHDRAWALS AND MEAN PAYOFFS *
*************************************************************

* Equilibrium predictions for treatments 5 (withdraw if y=1 or y=2), 6 (rollover for high and medium signals), and 8 (rollover y=0, x=h&y=1, withdraw y=2, x=l,m&y=1)
gen action_eq = 0
replace action_eq = 1 if treatment==1
replace action_eq = 1 if treatment==2
replace action_eq = 1 if treatment==3
replace action_eq = 1 if treatment==4
replace action_eq = 1 if treatment==4.5
replace action_eq = 1 if treatment==5&y==0
replace action_eq = 1 if treatment==6&signal_i!=0
replace action_eq = 1 if treatment==7
replace action_eq = 1 if treatment==8&y==0
replace action_eq = 1 if treatment==8&y==1&signal_i==2
replace action_eq = 1 if treatment==8.5

gen attack_size_eq = .
gen mm =.
gen nn=.
gen ss=.


forvalues t=1/30 {
* 30 is the number of periods (dropping the first 10)
forvalues i=1/222 {
* 222 is the total number of pairs 
summarize action_eq if ppair==`i'&Period==`t'
replace mm = r(mean) if ppair==`i'&Period==`t'
replace attack_size_eq = 2 if mm==1&ppair==`i'&Period==`t'
replace attack_size_eq = 1 if mm==0.5&ppair==`i'&Period==`t'
replace attack_size_eq = 0 if mm==0&ppair==`i'&Period==`t'
}
}
drop mm

gen attack_success_eq = 0
replace attack_success_eq = 1 if theta_2==2
replace attack_success_eq = 1 if attack_size_eq==2&theta_2==1

*****************************************
* FREQUENCIES OF WITHDRAWALS (Table 9A) *
*****************************************

* Generate theoretical benchmarks: equilibrium, empirical equilibrium, first best, and constrained efficiency

* Equilibrium
bysort treatment: tab action_eq if Period>10

* Realized
bysort treatment: tab action_i if Period>10

* Social planner: first best
gen action_sp = 0
replace action_sp = 1 if theta_2>0

* Constrained efficiency
gen action_sp_ce = 0
replace action_sp_ce = 1 if treatment==1
replace action_sp_ce = 1 if treatment==2
replace action_sp_ce = 1 if treatment==3
replace action_sp_ce = 0 if treatment==3&signal_i==0&signal_other==0
replace action_sp_ce = 1 if treatment==4
replace action_sp_ce = 1 if treatment==4.5
replace action_sp_ce = 0 if treatment==4.5&signal_i==0&signal_other==0
replace action_sp_ce = 1 if treatment==5&y==0
replace action_sp_ce = 1 if treatment==6&signal_i!=0&signal_other!=0
replace action_sp_ce = 1 if treatment==7
replace action_sp_ce = 0 if treatment==7&signal_i==0&signal_other==0
replace action_sp_ce = 1 if treatment==8&signal_i==0&signal_other==1&y==0
replace action_sp_ce = 1 if treatment==8&signal_i==1&signal_other==0&y==0
replace action_sp_ce = 1 if treatment==8&signal_i==0&signal_other==2&y==0
replace action_sp_ce = 1 if treatment==8&signal_i==2&signal_other==0&y==0
replace action_sp_ce = 1 if treatment==8&signal_i==1&signal_other==1&y==0
replace action_sp_ce = 1 if treatment==8&signal_i==1&signal_other==1&y==1
replace action_sp_ce = 1 if treatment==8&signal_i==1&signal_other==2&y==0
replace action_sp_ce = 1 if treatment==8&signal_i==2&signal_other==1&y==0
replace action_sp_ce = 1 if treatment==8&signal_i==1&signal_other==2&y==1
replace action_sp_ce = 1 if treatment==8&signal_i==2&signal_other==1&y==1
replace action_sp_ce = 1 if treatment==8&signal_i==2&signal_other==2
replace action_sp_ce = 1 if treatment==8.5
replace action_sp_ce = 0 if treatment==8.5&signal_i==0&signal_other==0

* replace for cases where it changes with C1's empirical equilibrium, i.e., Country 2's best response when agents in Country 1 behave exactly as they do in the data (as opposed to how they would under equilibrium)
gen action_sp_ce_emp = action_sp_ce

gen action_emp_eq = 0
replace action_emp_eq = 1 if treatment==1
replace action_emp_eq = 1 if treatment==2
replace action_emp_eq = 1 if treatment==3
replace action_emp_eq = 1 if treatment==4
replace action_emp_eq = 1 if treatment==4.5
replace action_emp_eq = 1 if treatment==5&y==0&signal_i!=0
replace action_emp_eq = 1 if treatment==6&signal_i!=0
replace action_emp_eq = 1 if treatment==7
replace action_emp_eq = 1 if treatment==8&y==0&signal_i==1
replace action_emp_eq = 1 if treatment==8&signal_i==2
replace action_emp_eq = 1 if treatment==8.5

replace action_sp_ce_emp = 1 if treatment==8&signal_i==1&signal_other==1&y==2
replace action_sp_ce_emp = 0 if treatment==5&signal_i==0&signal_other==0&y==0
replace action_sp_ce_emp = 0 if treatment==5&signal_i==0&signal_other==1&y==0
replace action_sp_ce_emp = 0 if treatment==5&signal_i==1&signal_other==0&y==0

gen action_obs_eq = 0
replace action_obs_eq = 1 if action_i==action_eq

gen action_obs_emp_eq = 0
replace action_obs_emp_eq = 1 if action_i==action_emp_eq

bysort treatment: tab action_sp if Period>10
bysort treatment: tab action_sp_ce if Period>10
bysort treatment: tab action_sp_ce_emp if Period>10

bysort treatment: ttest action_i=action_eq if Period>10
bysort treatment: ttest action_i=action_emp_eq if Period>10
bysort treatment: ttest action_i=action_sp if Period>10
bysort treatment: ttest action_i=action_sp_ce if Period>10
bysort treatment: ttest action_i=action_sp_ce_emp if Period>10
bysort treatment: ttest action_eq=action_sp if Period>10
bysort treatment: ttest action_eq=action_sp_ce if Period>10
bysort treatment: ttest action_eq=action_sp_ce_emp if Period>10

* Check how many instances of observed and equilibrium actions coincide with the social planner

bysort treatment: tab action_obs_eq if action_i==0&Period>10
bysort treatment: tab action_obs_emp_eq if action_i==0&Period>10

* Empirical equilibrium predictions: Best response in Country 2 when Country 1 agents behave exactly as observed in the C1 experiment (prediction changes only for treatment 5 and 8)

gen attack_size_emp_eq = .
gen m5=.
gen m8=.

* For treatment 5
forvalues t=1/30 {
forvalues i=1/24 {
summarize action_emp_eq if pair==`i'&treatment==5&Period==`t'
replace m5 = r(mean) if pair==`i'&treatment==5&Period==`t'
replace attack_size_emp_eq = 2 if m5==1&pair==`i'&treatment==5&Period==`t'
replace attack_size_emp_eq = 1 if m5==0.5&pair==`i'&treatment==5&Period==`t'
replace attack_size_emp_eq = 0 if m5==0&pair==`i'&treatment==5&Period==`t'
}
}
drop m5

* For treatment 8
forvalues t=1/30 {
forvalues i=1/22 {
summarize action_emp_eq if pair==`i'&treatment==8&Period==`t'
replace m8 = r(mean) if pair==`i'&treatment==8&Period==`t'
replace attack_size_emp_eq = 2 if m8==1&pair==`i'&treatment==8&Period==`t'
replace attack_size_emp_eq = 1 if m8==0.5&pair==`i'&treatment==8&Period==`t'
replace attack_size_emp_eq = 0 if m8==0&pair==`i'&treatment==8&Period==`t'
}
}
drop m8

gen attack_success_emp_eq = 0
replace attack_success_emp_eq = 1 if theta_2==2
replace attack_success_emp_eq = 1 if attack_size_emp_eq==2&theta_2==1

* Frequencies of withdrawals under empirical equilibrium
bysort treatment: tab action_emp_eq if Period>10
bysort treatment: ttest action_i=action_emp_eq if Period>10
bysort treatment: ttest action_emp_eq=action_sp if Period>10

* Check how many instances of empirical equilibrium actions coincide with the social planner and constrained efficiency benchmarks
gen action_emp_eq_sp = 0
gen action_emp_eq_sp_ce = 0
replace action_emp_eq_sp = 1 if action_emp_eq==action_sp
replace action_emp_eq_sp_ce = 1 if action_emp_eq==action_sp_ce
gen action_emp_eq_sp_w = 0
replace action_emp_eq_sp_w = 1 if action_i==action_sp&action_emp_eq==0
gen action_emp_eq_sp_ce_w = 0
replace action_emp_eq_sp_ce_w = 1 if action_i==action_sp_ce&action_emp_eq==0

bysort treatment: tab action_emp_eq_sp if action_emp_eq==0&Period>10
bysort treatment: tab action_emp_eq_sp_ce if action_emp_eq==0&Period>10


* Generate counters for cases where observed action in the experiment coincides with the efficiency benchmarks

* First best
gen action_obs_sp = 0
replace action_obs_sp = 1 if action_i==action_sp
gen action_obs_sp_w = 0
replace action_obs_sp_w = 1 if action_i==action_sp&action_i==0
gen action_eq_sp = 0
replace action_eq_sp = 1 if action_eq==action_sp
gen action_eq_sp_w = 0
replace action_eq_sp_w = 1 if action_i==action_sp&action_eq==0

bysort treatment: tab action_obs_sp if action_i==0&Period>10
bysort treatment: tab action_eq_sp if action_eq==0&Period>10

* Constrained efficiency
gen action_obs_sp_ce = 0
replace action_obs_sp_ce = 1 if action_i==action_sp_ce
gen action_obs_sp_ce_w = 0
replace action_obs_sp_ce_w = 1 if action_i==action_sp_ce&action_i==0
gen action_eq_sp_ce = 0
replace action_eq_sp_ce = 1 if action_eq==action_sp_ce
gen action_eq_sp_ce_w = 0
replace action_eq_sp_ce_w = 1 if action_i==action_sp_ce&action_eq==0

bysort treatment: tab action_obs_sp_ce if action_i==0&Period>10
bysort treatment: tab action_eq_sp_ce if action_eq==0&Period>10

* Constrained efficiency under empirical equilibrium
gen action_obs_sp_ce_emp = 0
replace action_obs_sp_ce_emp = 1 if action_i==action_sp_ce_emp
gen action_obs_sp_ce_emp_w = 0
replace action_obs_sp_ce_emp_w = 1 if action_i==action_sp_ce_emp&action_i==0
gen action_eq_sp_ce_emp = 0
replace action_eq_sp_ce_emp = 1 if action_eq==action_sp_ce_emp
gen action_eq_sp_ce_emp_w = 0
replace action_eq_sp_ce_emp_w = 1 if action_i==action_sp_ce_emp&action_eq==0

bysort treatment: tab action_obs_sp_ce_emp if action_i==0&Period>10
bysort treatment: tab action_eq_sp_ce_emp if action_eq==0&Period>10

*********************
* PAYOFFS (Table 9B)*
*********************

* Create theoretical payoffs to use as benchmarks for comparison of estimated payoffs (Table 9B)

* Equilibrium expected payoffs
gen profit_me_eq = .
replace profit_me_eq = 4 if action_eq==0
replace profit_me_eq = 0 if action_eq==1&theta_2==0
replace profit_me_eq = 0 if action_eq==1&attack_size_eq<2&theta_2==1
replace profit_me_eq = 20 if action_eq==1&theta_2==2
replace profit_me_eq = 20 if action_eq==1&attack_size_eq==2&theta_2==1

forvalues i=1/8 { 
summarize profit_me_eq if Period>10&treatment==`i'
gen pay_t`i'_eq = r(mean)
gen sd_t`i'_eq = r(sd)
}
summarize profit_me_eq if Period>10&treatment==4.5
gen pay_t45_eq = r(mean)
gen sd_t45_eq = r(sd)
summarize profit_me_eq if Period>10&treatment==8.5
gen pay_t85_eq = r(mean)
gen sd_t85_eq = r(sd)

* First best payoffs
gen profit_me_sp = 20
replace profit_me_sp = 4 if theta_2==0
bysort treatment: ttest profit_me=profit_me_eq if Period>10
bysort treatment: ttest profit_me=profit_me_sp if Period>10

* Constrained efficiency payoffs
gen profit_me_ce = .
replace profit_me_ce = 4 if action_sp_ce==0
replace profit_me_ce = 0 if action_sp_ce==1&theta_2==0
replace profit_me_ce = 20 if action_sp_ce==1&theta_2>=1

bysort treatment: ttest profit_me=profit_me_ce if Period>10

forvalues i=1/8 { 
summarize profit_me_ce if Period>10&treatment==`i'
gen pay_t`i'_ce = r(mean)
gen sd_t`i'_ce = r(sd)
}
summarize profit_me_ce if Period>10&treatment==4.5
gen pay_t45_ce = r(mean)
gen sd_t45_ce = r(sd)
summarize profit_me_ce if Period>10&treatment==8.5
gen pay_t85_ce = r(mean)
gen sd_t85_ce = r(sd)

* Constrained efficiency payoffs for empirical equilibrium
gen profit_me_ce_emp = .
replace profit_me_ce_emp = 4 if action_sp_ce_emp==0
replace profit_me_ce_emp = 0 if action_sp_ce_emp==1&theta_2==0
replace profit_me_ce_emp = 20 if action_sp_ce_emp==1&theta_2>=1

forvalues i=1/8 { 
summarize profit_me_ce_emp if Period>10&treatment==`i'
gen pay_t`i'_ce_emp = r(mean)
gen sd_t`i'_ce_emp = r(sd)
}
summarize profit_me_ce_emp if Period>10&treatment==4.5
gen pay_t45_ce_emp = r(mean)
gen sd_t45_ce_emp = r(sd)
summarize profit_me_ce_emp if Period>10&treatment==8.5
gen pay_t85_ce_emp = r(mean)
gen sd_t85_ce_emp = r(sd)

bysort treatment: ttest profit_me=profit_me_ce_emp if Period>10


* Empirical equilibrium expected payoffs
gen profit_me_emp_eq = .
replace profit_me_emp_eq = 4 if action_emp_eq==0
replace profit_me_emp_eq = 0 if action_emp_eq==1&theta_2==0
replace profit_me_emp_eq = 0 if action_emp_eq==1&attack_size_emp_eq<2&theta_2==1
replace profit_me_emp_eq = 20 if action_emp_eq==1&theta_2==2
replace profit_me_emp_eq = 20 if action_emp_eq==1&attack_size_emp_eq==2&theta_2==1

bysort treatment: summarize profit_me_emp_eq if Period>10

summarize profit_me_emp_eq if Period>10&treatment==5
gen pay_t5_emp_eq = r(mean)
gen sd_t5_emp_eq = r(sd)
ttest profit_me=profit_me_emp_eq if Period>10&treatment==5

summarize profit_me_emp_eq if Period>10&treatment==8
gen pay_t8_emp_eq = r(mean)
gen sd_t8_emp_eq = r(sd)
ttest profit_me=profit_me_emp_eq if Period>10&treatment==8

* Compare realized payoffs to payoffs under the different benchmarks
bysort treatment: ttest profit_me=profit_me_emp_eq if Period>10
bysort treatment: ttest profit_me=profit_me_sp if Period>10
bysort treatment: ttest profit_me=profit_me_ce if Period>10
bysort treatment: ttest profit_me=profit_me_ce_emp if Period>10



*************************************************
* Building the constrained efficiency benchmark *
*************************************************



gen PrL1 = .
gen PrM1 = 0.175
gen PrH1 = .
replace PrL1 = 0.175 if treatment<5
replace PrL1 = 0.65 if treatment>=5
replace PrH1 = 0.175 if treatment>=5
replace PrH1 = 0.65 if treatment<5

gen action_ce = .
gen Pr_M2 = .
gen Pr_H2 = .
gen Prx1_My = .
gen Prx2_My = .
gen Prx1_Hy = .
gen Prx2_Hy = .
gen Prx1_y = .
gen Prx2_y = .
gen Prx1_L = .
gen Prx2_L = .
gen Prx1_M = .
gen Prx2_M = .
gen PrM_y = .
gen Prx1_H = .
gen Prx2_H = .
gen PrH_y = .
gen PrL_y = .
gen PrL2_L1 = s
gen PrL2_M1 = (1-s)/2
gen PrL2_H1 = (1-s)/2
gen PrM2_L1 = (1-s)/2
gen PrM2_M1 = s
gen PrM2_H1 = (1-s)/2
gen PrH2_L1 = (1-s)/2
gen PrH2_M1 = (1-s)/2
gen PrH2_H1 = s
gen PrL1_y = .
gen PrM1_y = .
gen PrH1_y = .
gen Pry_L1 = .
gen Pry_M1 = .
gen Pry_H1 = .
gen Pry0_L1 = .
gen Pry1_L1 = .
gen Pry2_L1 = .
gen Pry0_M1 = .
gen Pry1_M1 = .
gen Pry2_M1 = .
gen Pry0_H1 = .
gen Pry1_H1 = .
gen Pry2_H1 = .
gen Prw0_L1 = .
gen Prw1_L1 = .
gen Prw2_L1 = .
gen Prw0_M1 = .
gen Prw1_M1 = .
gen Prw2_M1 = .
gen Prw0_H1 = .
gen Prw1_H1 = .
gen Prw2_H1 = .
gen denom = .

replace Prx1_L = r if signal_i==0
replace Prx2_L = r if signal_other==0
replace Prx1_L = (1-r)/2 if signal_i!=0
replace Prx2_L = (1-r)/2 if signal_other!=0
replace Prx1_M = r if signal_i==1
replace Prx2_M = r if signal_other==1
replace Prx1_M = (1-r)/2 if signal_i!=1
replace Prx2_M = (1-r)/2 if signal_other!=1
replace Prx1_H = r if signal_i==2
replace Prx2_H = r if signal_other==2
replace Prx1_H = (1-r)/2 if signal_i!=1
replace Prx2_H = (1-r)/2 if signal_other!=1

* According to theoretical equilibrium in C1
replace Prw0_L1 = (1-r)*(1-r) if PrL1==0.65
replace Prw0_L1 = 1 if PrL1<0.65
replace Prw0_M1 = (1+r)*(1+r)/4 if PrL1==0.65
replace Prw0_M1 = 1 if PrL1<0.65
replace Prw0_H1 = (1+r)*(1+r)/4 if PrL1==0.65
replace Prw0_H1 = 1 if PrL1<0.65
replace Prw1_L1 = r*(1-r) if PrL1==0.65
replace Prw1_L1 = 0 if PrL1<0.65
replace Prw1_M1 = (1-(r*r))/4 if PrL1==0.65
replace Prw1_M1 = 0 if PrL1<0.65
replace Prw1_H1 = (1-(r*r))/4 if PrL1==0.65
replace Prw1_H1 = 0 if PrL1<0.65
replace Prw2_L1 = r*r if PrL1==0.65
replace Prw2_L1 = 0 if PrL1<0.65
replace Prw2_M1 = (1-r)*(1-r)/4 if PrL1==0.65
replace Prw2_M1 = 0 if PrL1<0.65
replace Prw2_H1 = (1-r)*(1-r)/4 if PrL1==0.65
replace Prw2_H1 = 0 if PrL1<0.65

replace Pry0_L1 = (alpha*Prw0_L1) + (((1-alpha)/2)*Prw1_L1) + (((1-alpha)/2)*Prw2_L1)
replace Pry1_L1 = (alpha*Prw1_L1) + (((1-alpha)/2)*Prw0_L1) + (((1-alpha)/2)*Prw2_L1)
replace Pry2_L1 = (alpha*Prw2_L1) + (((1-alpha)/2)*Prw1_L1) + (((1-alpha)/2)*Prw0_L1)
replace Pry0_M1 = (alpha*Prw0_M1) + (((1-alpha)/2)*Prw1_M1) + (((1-alpha)/2)*Prw2_M1)
replace Pry1_M1 = (alpha*Prw1_M1) + (((1-alpha)/2)*Prw0_M1) + (((1-alpha)/2)*Prw2_M1)
replace Pry2_M1 = (alpha*Prw2_M1) + (((1-alpha)/2)*Prw1_M1) + (((1-alpha)/2)*Prw0_M1)
replace Pry0_H1 = (alpha*Prw0_H1) + (((1-alpha)/2)*Prw1_H1) + (((1-alpha)/2)*Prw2_H1)
replace Pry1_H1 = (alpha*Prw1_H1) + (((1-alpha)/2)*Prw0_H1) + (((1-alpha)/2)*Prw2_H1)
replace Pry2_H1 = (alpha*Prw2_H1) + (((1-alpha)/2)*Prw1_H1) + (((1-alpha)/2)*Prw0_H1)

replace Pry_L1 = Pry0_L1 if y==0
replace Pry_L1 = Pry1_L1 if y==1
replace Pry_L1 = Pry2_L1 if y==2
replace Pry_M1 = Pry0_M1 if y==0
replace Pry_M1 = Pry1_M1 if y==1
replace Pry_M1 = Pry2_M1 if y==2
replace Pry_H1 = Pry0_H1 if y==0
replace Pry_H1 = Pry1_H1 if y==1
replace Pry_H1 = Pry2_H1 if y==2

replace denom = (Pry_L1*PrL1) + (Pry_M1*PrM1) + (Pry_H1*PrH1)

replace PrL1_y = Pry_L1*PrL1 / denom
replace PrM1_y = Pry_M1*PrL1 / denom
replace PrH1_y = Pry_H1*PrL1 / denom

replace PrL_y = PrL2_L1*PrL1_y + PrL2_M1*PrM1_y + PrL2_H1*PrH1_y
replace PrM_y = PrM2_L1*PrL1_y + PrM2_M1*PrM1_y + PrM2_H1*PrH1_y
replace PrH_y = PrH2_L1*PrL1_y + PrH2_M1*PrM1_y + PrH2_H1*PrH1_y

replace Prx1_y = (Prx1_L*PrL_y) + (Prx1_M*PrM_y) +(Prx1_H*PrH_y)
replace Prx2_y =  (Prx2_L*PrL_y) + (Prx2_M*PrM_y) +(Prx2_H*PrH_y)

replace Prx1_My = Prx1_M*PrM_y
replace Prx2_My = Prx2_M*PrM_y
replace Prx1_Hy = Prx1_H*PrH_y
replace Prx2_Hy = Prx2_H*PrH_y



replace Pr_M2 = (Prx1_My*Prx2_My*PrM_y)/(Prx1_y*Prx2_y)
replace Pr_H2 = (Prx1_Hy*Prx2_My*PrH_y)/(Prx1_y*Prx2_y)

replace action_ce = 0 if 20*Pr_M2 + 20*Pr_H2 -4 < 0
replace action_ce = 1 if 20*Pr_M2 + 20*Pr_H2 -4 >= 0


gen action_ce_other = .
gsort ppair Period idd
replace action_ce_other = action_ce[_n+1] if ppair==ppair[_n+1]&Period==Period[_n+1]
replace action_ce_other = action_ce[_n-1] if ppair==ppair[_n-1]&Period==Period[_n-1]



******************************************
* THE COST OF FOLLOWING OTHERS, Table 10 *
******************************************

* First, separate people into the 2 categories

* Subjects who should rollover, according to equilibrium, but observe 1 (2) withdraw, so they withdraw
gen w_after_1 = 0
replace w_after_1 = 1 if action_eq==1&y>0&action_i==0
gen w_after_2 = 0
replace w_after_2 = 1 if action_eq==1&y==2&action_i==0

gen w_after_1_emp = 0
replace w_after_1_emp = 1 if action_emp_eq==1&y>0&action_i==0
gen w_after_2_emp = 0
replace w_after_2_emp = 1 if action_emp_eq==1&y==2&action_i==0

* Subjects who should withdraw, according to equilibrium, but observe 1 (2) rollover, so they rollover
gen r_after_1 = 0
replace r_after_1 = 1 if action_eq==0&y<2&action_i==1
gen r_after_2 = 0
replace r_after_2 = 1 if action_eq==0&y==0&action_i==1

gen r_after_1_emp = 0
replace r_after_1_emp = 1 if action_emp_eq==0&y<2&action_i==1
gen r_after_2_emp = 0
replace r_after_2_emp = 1 if action_emp_eq==0&y==0&action_i==1


forvalues i=1/8 {
summarize profit_me if Period>10&w_after_1==1&treatment==`i'
gen pay_t`i'_w_after_1 = r(mean)
summarize profit_me if Period>10&w_after_2==1&treatment==`i'
gen pay_t`i'_w_after_2 = r(mean)
summarize profit_me if Period>10&r_after_1==1&treatment==`i'
gen pay_t`i'_r_after_1 = r(mean)
summarize profit_me if Period>10&r_after_2==1&treatment==`i'
gen pay_t`i'_r_after_2 = r(mean)
}

summarize profit_me if Period>10&w_after_1==1&treatment==4.5
gen pay_t45_w_after_1 = r(mean)
summarize profit_me if Period>10&w_after_2==1&treatment==4.5
gen pay_t45_w_after_2 = r(mean)
summarize profit_me if Period>10&r_after_1==1&treatment==4.5
gen pay_t45_r_after_1 = r(mean)
summarize profit_me if Period>10&r_after_2==1&treatment==4.5
gen pay_t45_r_after_2 = r(mean)

summarize profit_me if Period>10&w_after_1==1&treatment==8.5
gen pay_t85_w_after_1 = r(mean)
summarize profit_me if Period>10&w_after_2==1&treatment==8.5
gen pay_t85_w_after_2 = r(mean)
summarize profit_me if Period>10&r_after_1==1&treatment==8.5
gen pay_t85_r_after_1 = r(mean)
summarize profit_me if Period>10&r_after_2==1&treatment==8.5
gen pay_t85_r_after_2 = r(mean)

forvalues i=1/4 {
ttest profit_me=profit_me_eq if Period>10&w_after_1==1&treatment==`i'
ttest profit_me=profit_me_eq if Period>10&w_after_2==1&treatment==`i'
}
ttest profit_me=profit_me_eq if Period>10&w_after_1==1&treatment==4.5
ttest profit_me=profit_me_eq if Period>10&w_after_2==1&treatment==4.5
ttest profit_me=profit_me_eq if Period>10&r_after_1==1&treatment==5
ttest profit_me=profit_me_eq if Period>10&w_after_1==1&treatment==6
ttest profit_me=profit_me_eq if Period>10&w_after_2==1&treatment==6
ttest profit_me=profit_me_eq if Period>10&r_after_1==1&treatment==6
ttest profit_me=profit_me_eq if Period>10&r_after_2==1&treatment==6
ttest profit_me=profit_me_eq if Period>10&w_after_1==1&treatment==7
ttest profit_me=profit_me_eq if Period>10&w_after_2==1&treatment==7
ttest profit_me=profit_me_eq if Period>10&w_after_1==1&treatment==8
ttest profit_me=profit_me_eq if Period>10&r_after_1==1&treatment==8
ttest profit_me=profit_me_eq if Period>10&w_after_1==1&treatment==8.5
ttest profit_me=profit_me_eq if Period>10&w_after_2==1&treatment==8.5


* Now with respect to empirical equilibrium predictions for treatments 5 and 8

ttest profit_me=profit_me_emp_eq if Period>10&r_after_1_emp==1&treatment==5
ttest profit_me=profit_me_emp_eq if Period>10&r_after_2_emp==1&treatment==5

ttest profit_me=profit_me_emp_eq if Period>10&w_after_1_emp==1&treatment==8
ttest profit_me=profit_me_emp_eq if Period>10&w_after_2_emp==1&treatment==8
ttest profit_me=profit_me_emp_eq if Period>10&r_after_1_emp==1&treatment==8
ttest profit_me=profit_me_emp_eq if Period>10&r_after_2_emp==1&treatment==8


*********************
* ROBUSTNESS CHECKS *
*********************

****************************************
* Control for risk aversion (Table 13) *
****************************************

xtlogit action_i signal_i y_rollover d_15 signal_i_15 y_rollover_15 ra if Period>10, i(idd)
xtlogit action_i signal_i y_rollover d_26 signal_i_26 y_rollover_26 ra if Period>10, i(idd)
xtlogit action_i signal_i y_rollover d_37 signal_i_37 y_rollover_37 ra if Period>10, i(idd)
xtlogit action_i signal_i y_rollover d_48 signal_i_48 y_rollover_48 ra if Period>10, i(idd)
xtlogit action_i signal_i y_rollover d_45_85 signal_i_45_85 y_rollover_45_85 ra if Period>10, i(idd)


*****************************************
* Longer sessions (50 rounds, Table 14) *
*****************************************

use 50_rounds_data.dta, clear

* Generate variable for public signal about the actions in Country 1 in terms of rolling over, not withdrawing
gen y_rollover = .
replace y_rollover = 0 if y==2
replace y_rollover = 1 if y==1
replace y_rollover = 2 if y==0

* Interacted variables
gen y_roll_signal_i = y_rollover*signal_i
gen signal_i_treat = signal_i*treatment
gen y_rollover_treat = y_rollover*treatment

* Rounds 11-30 (exactly as in main treatments)
xtlogit action_i signal_i y_rollover treatment signal_i_treat y_rollover_treat if period>10&period<=30, i(id)
mfx, predict(pu0)

* Last 40 rounds (taking into account additional rounds, only discarding first 10 rounds, as in main treatments)
xtlogit action_i signal_i y_rollover treatment signal_i_treat y_rollover_treat if period>10, i(id)
mfx, predict(pu0)

* Last 20 rounds (look at the effect of only the additional rounds)
xtlogit action_i signal_i y_rollover treatment signal_i_treat y_rollover_treat if period>30, i(id)
mfx, predict(pu0)


******************************************************************************
* Changing the frame of social signal y to standard public signal (Table 15) *
******************************************************************************

* Run main regression from paper to see if subjects overreact to public information when it's framed as a standard public signal
* interpretation of signal y: =0 (state is good, similar to 0 people withdrawing), =1 (state is medium), =2 (state is bad, similar to 2 people withdrawing)

use public_info_data, clear
* transform y in a similar way to y_rollover, so that y increases as the prospect of the state increase
gen yy = .
replace yy = 0 if y==2
replace yy = 1 if y==1
replace yy = 2 if y==0


* Interacted variables
gen signal_i_treat = signal_i*treatment
gen yy_treat = yy*treatment

xtlogit action_i signal_i yy treatment signal_i_treat yy_treat if Period>10, i(id)
mfx, predict(pu0)
